#[non_exhaustive]
pub enum Event<'a> { Id { id: String, }, Name { name: String, }, Coordinates { coordinates: Vec<u8>, }, State { state: WEnum<State>, }, Capabilities { capabilities: WEnum<WorkspaceCapabilities>, }, Removed, }
Available on crate feature wayland and Linux only.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


Id

workspace id

If this event is emitted, it will be send immediately after the ext_workspace_handle_v1 is created or when an id is assigned to a workspace (at most once during it’s lifetime).

An id will never change during the lifetime of the ext_workspace_handle_v1 and is guaranteed to be unique during it’s lifetime.

Ids are not human-readable and shouldn’t be displayed, use name for that purpose.

Compositors are expected to only send ids for workspaces likely stable across multiple sessions and can be used by clients to store preferences for workspaces. Workspaces without ids should be considered temporary and any data associated with them should be deleted once the respective object is lost.

Fields



Name

workspace name changed

This event is emitted immediately after the ext_workspace_handle_v1 is created and whenever the name of the workspace changes.

A name is meant to be human-readable and can be displayed to a user. Unlike the id it is neither stable nor unique.

Fields

name: String


Coordinates

workspace coordinates changed

This event is used to organize workspaces into an N-dimensional grid within a workspace group, and if supported, is emitted immediately after the ext_workspace_handle_v1 is created and whenever the coordinates of the workspace change. Compositors may not send this event if they do not conceptually arrange workspaces in this way. If compositors simply number workspaces, without any geometric interpretation, they may send 1D coordinates, which clients should not interpret as implying any geometry. Sending an empty array means that the compositor no longer orders the workspace geometrically.

Coordinates have an arbitrary number of dimensions N with an uint32 position along each dimension. By convention if N > 1, the first dimension is X, the second Y, the third Z, and so on. The compositor may chose to utilize these events for a more novel workspace layout convention, however. No guarantee is made about the grid being filled or bounded; there may be a workspace at coordinate 1 and another at coordinate 1000 and none in between. Within a workspace group, however, workspaces must have unique coordinates of equal dimensionality.

Fields

coordinates: Vec<u8>


State

the state of the workspace changed

This event is emitted immediately after the ext_workspace_handle_v1 is created and each time the workspace state changes, either because of a compositor action or because of a request in this protocol.

Missing states convey the opposite meaning, e.g. an unset active bit means the workspace is currently inactive.

Fields

state: WEnum<State>


Capabilities

compositor capabilities

This event advertises the capabilities supported by the compositor. If a capability isn’t supported, clients should hide or disable the UI elements that expose this functionality. For instance, if the compositor doesn’t advertise support for removing workspaces, a button triggering the remove request should not be displayed.

The compositor will ignore requests it doesn’t support. For instance, a compositor which doesn’t advertise support for remove will ignore remove requests.

Compositors must send this event once after creation of an ext_workspace_handle_v1 . When the capabilities change, compositors must send this event again.

Fields

capabilities: WEnum<WorkspaceCapabilities>

capabilities



Removed

this workspace has been removed

This event is send when the workspace associated with the ext_workspace_handle_v1 has been removed. After sending this request, the compositor will immediately consider the object inert. Any requests will be ignored except the destroy request.

It is guaranteed there won’t be any more events referencing this ext_workspace_handle_v1.

The compositor must only remove a workspaces not currently belonging to any workspace_group.

Implementations



impl<'a> Event<'a>

pub fn opcode(&self) -> u16

Get the opcode number of this message